import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

/**
 * The frog moves in the world looking for flys to eat.
 * 
 * @author J Woodard 
 * @version 1.0
 */
public class Frog extends Animal
{

    private GreenfootImage image1;
    private GreenfootImage image2;
   
    /**
     * constructor 
     */
    public Frog()
    {
        image1 = new GreenfootImage("frog.png");
        image2 = new GreenfootImage("butterfly.png");
        setImage(image1);
    }
    
   /**
     * Act - do whatever the Frog wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
   public void act() 
    {
        if (atWorldEdge())
        {
            turn(13);
        }
        move(7);
        randomTurn();
        lookForFly();
        updateImage();
    } 
    
    /**
     * Test if actor is at the edge of the world, if so, then turn
     */
    public boolean atWorldEdge()
    {
        World w = getWorld();
        if ( getX() < 20 || getX() > w.getWidth() - 20 )
        {
            return true;
        }
        if ( getY() < 20 || getY() > w.getHeight() - 20 )
        {
            return true;
        }
        else
        {
            return false;
        }
    }
    
    /**
     * Checks if the frog has found a fly, and if so, it eats the fly.
     * If no fly is found the frog continues to look.
     */
    public void lookForFly()
    {
        
        
        if ( canSee (Fly.class) )
        {
            eat(Fly.class);
            Greenfoot.playSound("slurp.wav");
            Greenfoot.playSound("fanfare.wav");
            Greenfoot.stop();
        }
    }
    
    /**
     * Allows the frog to randomly turn in both (right and left) directions
     * at least 10% of the time.
     */
    public void randomTurn()
    {
        if (Greenfoot.getRandomNumber(100) < 10)
        {
            turn(Greenfoot.getRandomNumber(90) - 45);
        }
    }
    
    /**
     * Updates and alternate between two images
     */
    public void updateImage()
    {
        if ( getImage() == image1 && atWorldEdge())
        {
            setImage(image2);
        }
        else
        {
            setImage(image1);
        }
    }
}
